@@ -1,5 +1,5 @@
 setMethodS3("makeSmoothSplinePredict", "numeric", function(x, y, df=5, ...) {
-  .Deprecated("makeSmoothSplinePredict", msg="Internal function makeSmoothSplinePredict() is deprecated, because it is no longer used.  It will eventually be removed from the package.");
+  .Defunct("makeSmoothSplinePredict", msg="Internal function makeSmoothSplinePredict() is deprecated, because it is no longer used.  It will eventually be removed from the package.");
 
   # Argument 'y':
   if (length(x) != length(y)) {
@@ -10,7 +10,8 @@ setMethodS3("makeSmoothSplinePredict", "numeric", function(x, y, df=5, ...) {
   ok <- which(is.finite(x) & is.finite(y));
   x <- x[ok];
   y <- y[ok];
-  rm(ok);
+  # Not needed anymore
+  ok <- NULL;
 
   specs <- list(
     xRange = range(x),
@@ -19,11 +20,12 @@ setMethodS3("makeSmoothSplinePredict", "numeric", function(x, y, df=5, ...) {
 
   # Fit smooth function
   fit <- smooth.spline(x,y, df=df, ...);
-  rm(x,y);
+  # Not needed anymore
+  x <- y <- NULL;
 
   # Create predict() function that handles missing values.
   predFcn <- function(x, ...) {
-    yPred <- rep(as.double(NA), length(x));
+    yPred <- rep(as.double(NA), times=length(x));
     ok <- which(!is.na(x));  # Allows for -/+Inf:s though
     yPred[ok] <- predict(fit, x=x[ok], ...)$y;
     yPred;
@@ -39,6 +41,8 @@ setMethodS3("makeSmoothSplinePredict", "numeric", function(x, y, df=5, ...) {
 
 ###########################################################################
 # HISTORY:
+# 2013-08-04
+# o CLEAN UP: Defuncted makeSmoothSplinePredict().
 # 2009-02-08
 # o CLEAN UP: Deprecated makeSmoothSplinePredict(), because it is not used.
 # 2008-10-08
